==> aws-java-sdk-support-1.10.55-sources.jar: com/amazonaws/services/support/model/transform/DescribeCasesResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.support.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.support.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * DescribeCasesResult JSON Unmarshaller
 */
public class DescribeCasesResultJsonUnmarshaller implements
        Unmarshaller<DescribeCasesResult, JsonUnmarshallerContext> {

    public DescribeCasesResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        DescribeCasesResult describeCasesResult = new DescribeCasesResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("cases", targetDepth)) {
                    context.nextToken();
                    describeCasesResult
                            .setCases(new ListUnmarshaller<CaseDetails>(
                                    CaseDetailsJsonUnmarshaller.getInstance())
                                    .unmarshall(context));
                }
                if (context.testExpression("nextToken", targetDepth)) {
                    context.nextToken();
                    describeCasesResult.setNextToken(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return describeCasesResult;
    }

    private static DescribeCasesResultJsonUnmarshaller instance;

    public static DescribeCasesResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeCasesResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-support-1.11.26-sources.jar: com/amazonaws/services/support/model/transform/DescribeCasesResultJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.support.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.support.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * DescribeCasesResult JSON Unmarshaller
 */
public class DescribeCasesResultJsonUnmarshaller implements
        Unmarshaller<DescribeCasesResult, JsonUnmarshallerContext> {

    public DescribeCasesResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        DescribeCasesResult describeCasesResult = new DescribeCasesResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("cases", targetDepth)) {
                    context.nextToken();
                    describeCasesResult
                            .setCases(new ListUnmarshaller<CaseDetails>(
                                    CaseDetailsJsonUnmarshaller.getInstance())
                                    .unmarshall(context));
                }
                if (context.testExpression("nextToken", targetDepth)) {
                    context.nextToken();
                    describeCasesResult.setNextToken(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return describeCasesResult;
    }

    private static DescribeCasesResultJsonUnmarshaller instance;

    public static DescribeCasesResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeCasesResultJsonUnmarshaller();
        return instance;
    }
}
